@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import operator
 import math
 
@@ -198,6 +198,9 @@ class PopdownMixin(object):
             if value:
                 return False
         entry.set_active(active)
+        if active == -1:
+            # When setting no item GTK doesn't clear the entry
+            entry.child.set_text('')
         return True
 
 
