@@ -9,7 +9,7 @@ import logging
 import sys
 import locale
 import gtk
-import site
+import pkg_resources
 
 from tryton.exceptions import TrytonError
 from tryton import __version__
@@ -17,13 +17,6 @@ from tryton import __version__
 _ = gettext.gettext
 
 
-def get_home_dir():
-    if os.name == 'nt':
-        return os.path.join(os.environ['HOMEDRIVE'], os.environ['HOMEPATH']
-            ).decode(sys.getfilesystemencoding()).encode('utf-8')
-    return os.environ['HOME']
-
-
 def get_config_dir():
     if os.name == 'nt':
         return os.path.join(os.environ['APPDATA'], '.config', 'tryton',
@@ -58,8 +51,8 @@ class ConfigManager(object):
             'client.maximize': False,
             'client.save_width_height': True,
             'client.save_tree_state': True,
+            'client.fast_tabbing': True,
             'client.spellcheck': False,
-            'client.default_path': get_home_dir(),
             'client.lang': locale.getdefaultlocale()[0],
             'client.language_direction': 'ltr',
             'client.email': '',
@@ -171,27 +164,22 @@ class ConfigManager(object):
             self.defaults.get(key)))
 
 CONFIG = ConfigManager()
+CURRENT_DIR = unicode(os.path.dirname(__file__),
+    sys.getfilesystemencoding())
 if (os.name == 'nt' and hasattr(sys, 'frozen')
         and os.path.basename(sys.executable) == 'tryton.exe'):
     CURRENT_DIR = os.path.dirname(unicode(sys.executable,
         sys.getfilesystemencoding()))
-else:
-    CURRENT_DIR = os.path.abspath(os.path.normpath(os.path.join(
-        unicode(os.path.dirname(__file__), sys.getfilesystemencoding()),
-        '..')))
+elif (os.name == 'mac'
+        or (hasattr(os, 'uname') and os.uname()[0] == 'Darwin')):
+    resources = os.path.join(os.path.dirname(sys.argv[0]), '..', 'Resources')
+    if os.path.isdir(resources):
+        CURRENT_DIR = resources
 
-for dir in [CURRENT_DIR, getattr(site, 'USER_BASE', sys.prefix), sys.prefix]:
-    PIXMAPS_DIR = os.path.join(dir, 'share', 'pixmaps', 'tryton')
-    if os.path.isdir(PIXMAPS_DIR):
-        break
+PIXMAPS_DIR = os.path.join(CURRENT_DIR, 'data', 'pixmaps', 'tryton')
+if not os.path.isdir(PIXMAPS_DIR):
+    PIXMAPS_DIR = pkg_resources.resource_filename(
+        'tryton', 'data/pixmaps/tryton')
 
 TRYTON_ICON = gtk.gdk.pixbuf_new_from_file(
-        os.path.join(PIXMAPS_DIR, 'tryton-icon.png').encode('utf-8'))
-
-
-def _data_dir():
-    data_dir = os.path.join(CURRENT_DIR, 'share', 'tryton')
-    if not os.path.isdir(data_dir):
-        data_dir = os.path.join(sys.prefix, 'share', 'tryton')
-    return data_dir
-DATA_DIR = _data_dir()
+    os.path.join(PIXMAPS_DIR, 'tryton-icon.png').encode('utf-8'))
