@@ -13,7 +13,7 @@ from tryton.gui.window.win_import import WinImport
 from tryton.gui.window.attachment import Attachment
 from tryton.gui.window.revision import Revision
 from tryton.signal_event import SignalEvent
-from tryton.common import message, sur, sur_3b, COLOR_SCHEMES, timezoned_date
+from tryton.common import message, sur, sur_3b, timezoned_date
 import tryton.common as common
 from tryton.common import RPCExecute, RPCException
 from tryton.common.datetime_strftime import datetime_strftime
@@ -190,12 +190,6 @@ class Form(SignalEvent, TabContent):
     def destroy(self):
         self.screen.destroy()
 
-    def ids_get(self):
-        return self.screen.ids_get()
-
-    def id_get(self):
-        return self.screen.id_get()
-
     def sig_attach(self, widget=None):
         record = self.screen.current_record
         if not record or record.id < 0:
@@ -218,9 +212,9 @@ class Form(SignalEvent, TabContent):
             self.buttons['attach'].set_stock_id('tryton-attachment-hi')
         else:
             self.buttons['attach'].set_stock_id('tryton-attachment')
-        record_id = self.id_get()
+        record = self.screen.current_record
         self.buttons['attach'].props.sensitive = bool(
-            record_id >= 0 and record_id is not False)
+            record.id >= 0 if record else False)
 
     def sig_switch(self, widget=None):
         if not self.modified_save():
@@ -228,9 +222,10 @@ class Form(SignalEvent, TabContent):
         self.screen.switch_view()
 
     def sig_logs(self, widget=None):
-        obj_id = self.id_get()
-        if obj_id < 0 or obj_id is False:
-            self.message_info(_('You have to select one record!'))
+        current_record = self.screen.current_record
+        if not current_record or current_record.id < 0:
+            self.message_info(
+                _('You have to select one record.'), gtk.MESSAGE_INFO)
             return False
 
         fields = [
@@ -242,7 +237,7 @@ class Form(SignalEvent, TabContent):
         ]
 
         try:
-            res = RPCExecute('model', self.model, 'read', [obj_id],
+            res = RPCExecute('model', self.model, 'read', [current_record.id],
                 [x[0] for x in fields], context=self.screen.context)
         except RPCException:
             return
@@ -314,15 +309,16 @@ class Form(SignalEvent, TabContent):
             msg = _('Are you sure to remove those records?')
         if sur(msg):
             if not self.screen.remove(delete=True, force_remove=True):
-                self.message_info(_('Records not removed!'))
+                self.message_info(_('Records not removed.'), gtk.MESSAGE_ERROR)
             else:
-                self.message_info(_('Records removed!'), 'green')
+                self.message_info(_('Records removed.'), gtk.MESSAGE_INFO)
 
     def sig_import(self, widget=None):
         WinImport(self.model, self.screen.context)
 
     def sig_save_as(self, widget=None):
-        export = WinExport(self.model, self.ids_get(),
+        export = WinExport(self.model,
+            [r.id for r in self.screen.selected_records],
             context=self.screen.context)
         for name in self.screen.current_view.get_fields():
             export.sel_field(name)
@@ -334,7 +330,7 @@ class Form(SignalEvent, TabContent):
             if not self.modified_save():
                 return
         self.screen.new()
-        self.message_info('')
+        self.message_info()
         self.activate_save()
 
     def sig_copy(self, widget=None):
@@ -342,9 +338,9 @@ class Form(SignalEvent, TabContent):
             return
         if not self.modified_save():
             return
-        self.screen.copy()
-        self.message_info(_('Working now on the duplicated record(s)!'),
-            'green')
+        if self.screen.copy():
+            self.message_info(_('Working now on the duplicated record(s).'),
+                gtk.MESSAGE_INFO)
 
     def sig_save(self, widget=None):
         if widget:
@@ -353,24 +349,24 @@ class Form(SignalEvent, TabContent):
         if not common.MODELACCESS[self.model]['write']:
             return
         if self.screen.save_current():
-            self.message_info(_('Record saved!'), 'green')
+            self.message_info(_('Record saved.'), gtk.MESSAGE_INFO)
             return True
         else:
-            self.message_info(_('Invalid form!'))
+            self.message_info(self.screen.invalid_message(), gtk.MESSAGE_ERROR)
             return False
 
     def sig_previous(self, widget=None):
         if not self.modified_save():
             return
         self.screen.display_prev()
-        self.message_info('')
+        self.message_info()
         self.activate_save()
 
     def sig_next(self, widget=None):
         if not self.modified_save():
             return
         self.screen.display_next()
-        self.message_info('')
+        self.message_info()
         self.activate_save()
 
     def sig_reload(self, test_modified=True):
@@ -391,7 +387,7 @@ class Form(SignalEvent, TabContent):
                     set_cursor = True
                     break
         self.screen.display(set_cursor=set_cursor)
-        self.message_info('')
+        self.message_info()
         self.activate_save()
         return True
 
@@ -440,16 +436,6 @@ class Form(SignalEvent, TabContent):
         menu.show_all()
         menu.popup(None, None, menu_position, 0, 0)
 
-    def message_info(self, message, color='red'):
-        if message:
-            self.info_label.set_label(message)
-            self.eb_info.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(
-                COLOR_SCHEMES.get(color, 'white')))
-            self.eb_info.show_all()
-        else:
-            self.info_label.set_label('')
-            self.eb_info.hide()
-
     def _record_message(self, screen, signal_data):
         name = '_'
         if signal_data[0]:
@@ -467,7 +453,7 @@ class Form(SignalEvent, TabContent):
         if signal_data[1] < signal_data[2]:
             msg += _(' of ') + str(signal_data[2])
         self.status_label.set_text(msg)
-        self.message_info('')
+        self.message_info()
         self.activate_save()
         self.url_entry.set_text(self.screen.get_url())
 
@@ -626,7 +612,8 @@ class Form(SignalEvent, TabContent):
                             'model': self.model,
                             'ids': [r.id
                                 for r in self.screen.selected_records],
-                            'id': self.id_get(),
+                            'id': (self.screen.current_record.id
+                                if self.screen.current_record else None),
                             }), func)
                 menuitem._update_action = True
                 menu.add(menuitem)
