@@ -43,6 +43,38 @@ class Shortcuts(object):
         notebook.append_page(self._fill_table(shortcuts),
                 gtk.Label(_('Edition Widgets')))
 
+        shortcuts = [
+            (_('Move Cursor'),),
+            ('<Right>', _('Move to right')),
+            ('<Left>', _('Move to left')),
+            ('<Up>', _('Move up')),
+            ('<Down>', _('Move down')),
+            ('<Page Up>', _('Move up of one page')),
+            ('<Page Down>', _('Move down of one page')),
+            ('<Home>', _('Move to top')),
+            ('<End>', _('Move to bottom')),
+            ('<Backspace>', _('Move to parent')),
+            (_('Selection'),),
+            ('<Ctrl> + a', _('Select all')),
+            ('<Ctrl> + /', _('Select all')),
+            ('<Shift> + <Ctrl> + a', _('Unselect all')),
+            ('<Shift> + <Ctrl> + /', _('Unselect all')),
+            ('<Backspace>', _('Select parent')),
+            ('<Space>', _('Select/Activate current row')),
+            ('<Shift> + <Space>', _('Select/Activate current row')),
+            ('<Return>', _('Select/Activate current row')),
+            ('<Enter>', _('Select/Activate current row')),
+            ('<Ctrl> + <Space>', _('Toggle selection')),
+            (_('Expand/Collapse'),),
+            ('+', _('Expand row')),
+            ('-', _('Collapse row')),
+            ('<Space>', _('Toggle row')),
+            ('<Shift> + <Left>', _('Expand all rows')),
+            ('<Shift> + <Right>', _('Collapse all rows')),
+            ]
+        notebook.append_page(self._fill_table(shortcuts),
+                gtk.Label(_('Tree view')))
+
         self.dialog.show_all()
 
     def _fill_table(self, shortcuts):
