@@ -397,11 +397,12 @@ class Record(SignalEvent):
         return res
 
     def _get_invalid_fields(self):
-        res = []
+        fields = {}
         for fname, field in self.group.fields.iteritems():
-            if not field.get_state_attrs(self).get('valid', True):
-                res.append((fname, field.attrs['string']))
-        return dict(res)
+            invalid = field.get_state_attrs(self).get('invalid')
+            if invalid:
+                fields[fname] = invalid
+        return fields
 
     invalid_fields = property(_get_invalid_fields)
 
@@ -435,7 +436,9 @@ class Record(SignalEvent):
         later = {}
         for fieldname, value in val.iteritems():
             if fieldname == '_timestamp':
-                self._timestamp = value
+                # Always keep the older timestamp
+                if not self._timestamp:
+                    self._timestamp = value
                 continue
             if fieldname not in self.group.fields:
                 if fieldname == 'rec_name':
@@ -460,13 +463,9 @@ class Record(SignalEvent):
             self.signal('record-changed')
 
     def set_on_change(self, values):
-        later = {}
         for fieldname, value in values.items():
             if fieldname not in self.group.fields:
                 continue
-            if isinstance(self.group.fields[fieldname], fields.O2MField):
-                later[fieldname] = value
-                continue
             if isinstance(self.group.fields[fieldname], (fields.M2OField,
                         fields.ReferenceField)):
                 field_rec_name = fieldname + '.rec_name'
@@ -475,14 +474,6 @@ class Record(SignalEvent):
                 elif field_rec_name in self.value:
                     del self.value[field_rec_name]
             self.group.fields[fieldname].set_on_change(self, value)
-        for fieldname, value in later.items():
-            # on change recursion checking is done only for x2many
-            field_x2many = self.group.fields[fieldname]
-            try:
-                field_x2many.in_on_change = True
-                field_x2many.set_on_change(self, value)
-            finally:
-                field_x2many.in_on_change = False
 
     def reload(self, fields=None):
         if self.id < 0:
