@@ -17,6 +17,7 @@ class MultiSelection(Widget, SelectionMixin):
         self.widget = gtk.ScrolledWindow()
         self.widget.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.widget.set_shadow_type(gtk.SHADOW_ETCHED_IN)
+        self.widget.get_accessible().set_name(attrs.get('string', ''))
 
         self.model = gtk.ListStore(gobject.TYPE_INT, gobject.TYPE_STRING)
         self.tree = TreeViewControl()
@@ -38,9 +39,6 @@ class MultiSelection(Widget, SelectionMixin):
         self.init_selection()
         self.id2path = {}
 
-    def _color_widget(self):
-        return self.tree
-
     @property
     def modified(self):
         if self.record and self.field:
