@@ -4,7 +4,9 @@ import gtk
 import gettext
 
 from .many2one import Many2One
-from tryton.common.selection import SelectionMixin, PopdownMixin
+from tryton.common.selection import SelectionMixin, PopdownMixin, \
+        selection_shortcuts
+from tryton.config import CONFIG
 
 _ = gettext.gettext
 
@@ -16,10 +18,14 @@ class Reference(Many2One, SelectionMixin, PopdownMixin):
 
         self.widget_combo = gtk.ComboBoxEntry()
         child = self.widget_combo.get_child()
-        child.set_editable(False)
-        child.connect('changed', self.sig_changed_combo)
-        self.widget.pack_start(self.widget_combo, expand=False, fill=True)
+        child.connect('activate', lambda *a: self._focus_out())
+        child.connect('focus-out-event', lambda *a: self._focus_out())
+        child.get_accessible().set_name(attrs.get('string', ''))
+        self.widget_combo.connect('changed', self.sig_changed_combo)
+        selection_shortcuts(self.widget_combo)
+        self.widget_combo.set_focus_chain([child])
 
+        self.widget.pack_start(self.widget_combo, expand=False, fill=True)
         self.widget.pack_start(gtk.Label('-'), expand=False, fill=False)
 
         self.init_selection()
@@ -41,14 +47,15 @@ class Reference(Many2One, SelectionMixin, PopdownMixin):
                 return model, name
         return '', ''
 
-    def _readonly_set(self, value):
-        super(Reference, self)._readonly_set(value)
-        if not value:
-            self.widget.set_focus_chain([self.widget_combo, self.wid_text])
-
     def _set_button_sensitive(self):
         super(Reference, self)._set_button_sensitive()
-        self.widget_combo.set_sensitive(not self._readonly)
+        self.widget_combo.child.set_editable(not self._readonly)
+        self.widget_combo.set_button_sensitivity(
+            gtk.SENSITIVITY_OFF if self._readonly else gtk.SENSITIVITY_AUTO)
+        if self._readonly and CONFIG['client.fast_tabbing']:
+            self.widget.set_focus_chain([])
+        else:
+            self.widget.unset_focus_chain()
 
     @property
     def modified(self):
@@ -121,17 +128,13 @@ class Reference(Many2One, SelectionMixin, PopdownMixin):
         else:
             model, value = None, None
         super(Reference, self).set_text(value)
-
-        active = -1
-        combo_model = self.widget_combo.get_model()
-        for i, selection in enumerate(combo_model):
-            if selection[1] == model:
-                active = i
-                break
-        self.widget_combo.set_active(active)
-        if active == -1:
-            # When setting no item GTK doesn't clear the entry
-            self.widget_combo.child.set_text('')
+        self.widget_combo.handler_block_by_func(self.sig_changed_combo)
+        if not self.set_popdown_value(self.widget_combo, model):
+            text = self.get_inactive_selection(model)
+            self.set_popdown(
+                self.selection[:] + [(model, text)], self.widget_combo)
+            self.set_popdown_value(self.widget_combo, value)
+        self.widget_combo.handler_unblock_by_func(self.sig_changed_combo)
 
     def display(self, record, field):
         self.update_selection(record, field)
