@@ -484,7 +484,7 @@ class WinExport(NoModal):
             return True
         except IOError, exception:
             common.warning(_("Operation failed!\nError message:\n%s")
-                % (exception.faultCode,), _('Error'))
+                % exception, _('Error'))
             return False
 
     def drag_begin(self, treeview, context):
