@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import xmlrpclib
 try:
     import simplejson as json
@@ -15,6 +15,7 @@ import StringIO
 import hashlib
 import base64
 import threading
+import errno
 from functools import partial
 from contextlib import contextmanager
 
@@ -55,8 +56,11 @@ def object_hook(dct):
         elif dct['__class__'] == 'time':
             return datetime.time(dct['hour'], dct['minute'], dct['second'],
                 dct['microsecond'])
-        elif dct['__class__'] == 'buffer':
-            return buffer(base64.decodestring(dct['base64']))
+        elif dct['__class__'] == 'timedelta':
+            return datetime.timedelta(seconds=dct['seconds'])
+        elif dct['__class__'] == 'bytes':
+            cast = bytearray if bytes == str else bytes
+            return cast(base64.decodestring(dct['base64']))
         elif dct['__class__'] == 'Decimal':
             return Decimal(dct['decimal'])
     return dct
@@ -93,8 +97,12 @@ class JSONEncoder(json.JSONEncoder):
                 'second': obj.second,
                 'microsecond': obj.microsecond,
                 }
-        elif isinstance(obj, buffer):
-            return {'__class__': 'buffer',
+        elif isinstance(obj, datetime.timedelta):
+            return {'__class__': 'timedelta',
+                'seconds': obj.total_seconds(),
+                }
+        elif isinstance(obj, (bytes, bytearray)):
+            return {'__class__': 'bytes',
                 'base64': base64.encodestring(obj),
                 }
         elif isinstance(obj, Decimal):
@@ -170,7 +178,7 @@ class Transport(xmlrpclib.Transport, xmlrpclib.SafeTransport):
     def make_connection(self, host):
         if self._connection and host == self._connection[0]:
             return self._connection[1]
-        host, extra_headers, x509 = self.get_host_info(host)
+        host, self._extra_headers, x509 = self.get_host_info(host)
 
         ca_certs = self.__ca_certs
         cert_reqs = ssl.CERT_REQUIRED if ca_certs else ssl.CERT_NONE
@@ -192,6 +200,7 @@ class Transport(xmlrpclib.Transport, xmlrpclib.SafeTransport):
             self._connection[1].connect()
             sock = self._connection[1].sock
             sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+            sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
 
         def https_connection():
             self._connection = host, HTTPSConnection(host,
@@ -200,6 +209,7 @@ class Transport(xmlrpclib.Transport, xmlrpclib.SafeTransport):
                 self._connection[1].connect()
                 sock = self._connection[1].sock
                 sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+                sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
                 try:
                     peercert = sock.getpeercert(True)
                 except socket.error:
@@ -261,8 +271,8 @@ class ServerProxy(xmlrpclib.ServerProxy):
                 verbose=self.__verbose
                 )
         except (socket.error, httplib.HTTPException), v:
-            # trap  'Broken pipe'
-            if isinstance(v, socket.error) and v.args[0] != 32:
+            if (isinstance(v, socket.error)
+                    and v.args[0] == errno.EPIPE):
                 raise
             # try one more time
             self.__transport.close()
